/* @(#)stdarg.h	1.1 13/04/30 Copyright 2013 J. Schilling */
/*
 *	Generic header for users of stdarg.h ...
 *
 *	Copyright (c) 2013 J. Schilling
 */
/*
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * See the file CDDL.Schily.txt in this distribution for details.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file CDDL.Schily.txt from this distribution.
 */

#ifndef	_SCHILY_STDARG_H
#define	_SCHILY_STDARG_H

#ifndef	_SCHILY_MCONFIG_H
#include <schily/mconfig.h>
#endif

#ifndef	_SCHILY_VARARGS_H
#include <schily/varargs.h>
#endif

#endif	/* _SCHILY_STDARG_H */
