/* @(#)err_arch.h	1.1 12/12/03 Copyright 2012 J. Schilling */
/*
 *	#error include for unconfigured architecture
 *
 *	Copyright (c) 2012 J. Schilling
 */
/*
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * See the file CDDL.Schily.txt in this distribution for details.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file CDDL.Schily.txt from this distribution.
 */

#ifndef _SCHILY_ERR_ARCH_H
#define	_SCHILY_ERR_ARCH_H

#error unconfigured architecture

#endif /* _SCHILY_ERR_ARCH_H */
